.. _staying_up_to_date:

*************************
Staying Up to Date 
*************************

If you would like to receive notifications of new code releases, sign up for the google group 

https://groups.google.com/forum/#!forum/Corrfunc

Feel free to ask questions about the code on the group. However, note that all
exchanges on the groups are subject to `Astropy Community Code of Conduct <http://www.astropy.org/about.html#codeofconduct>`_,
which is basically, "Be nice!". If you are unsure about some technical aspect
of the code, then feel free to email the author (`Manodeep Sinha
<mailto:manodeep@gmail.com>`_).


